==> tamejs-0.2.1.tgz: package/test/cases/1.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var slots = { } ;
    
    exports [ "rendezvous & windowing example" ] = {
    
    
    run :
    function  (ev) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            function call (i, ev) {
                var __tame_this = this;
                var __tame_fn_10 = function (__tame_k) {
                    slots [ i ] = 1 ;
                    var __tame_fn_6 = function (__tame_k) {
                        var __tame_fn_7 = function (__tame_k) {
                            var __tame_ev = new tame.Event (__tame_k);
                            var __tame_fn_8 = function (__tame_k) {
                                setTimeout (
                                __tame_ev.mkevent ()
                                , 10*Math.random ( ) ) ;
                                tame.callChain([__tame_k]);
                            };
                            __tame_fn_8(tame.end);
                            __tame_ev.trigger();
                        };
                        var __tame_fn_9 = function (__tame_k) {
                            slots [ i ] |= 2 ;
                            ev ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_7, __tame_fn_9, __tame_k]);
                    };
                    tame.callChain([__tame_fn_6, __tame_k]);
                };
                tame.callChain([__tame_fn_10, __tame_k]);
            }
            ;
            function window (n, window, ev) {
                var __tame_this = this;
                var __tame_fn_22 = function (__tame_k) {
                    var rv = new tame .Rendezvous ( ) ;
                    var nsent = 0 ;
                    var nrecv = 0 ;
                    var __tame_fn_11 = function (__tame_k) {
                        var __tame_fn_12 = function (__tame_k) {
                            var __tame_k_implicit =  {};
                            var __tame_fn_13 = function (__tame_k) {
                                if (nrecv < n) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        var __tame_fn_15 = function (__tame_k) {
                                            call ( nsent , rv .mkev ( nsent ) ) ;
                                            nsent ++ ;
                                            tame.callChain([__tame_k]);
                                        };
                                        var __tame_fn_20 = function (__tame_k) {
                                            var res ;
                                            var __tame_fn_16 = function (__tame_k) {
                                                var __tame_fn_17 = function (__tame_k) {
                                                    var __tame_ev = new tame.Event (__tame_k);
                                                    var __tame_fn_18 = function (__tame_k) {
                                                        rv .wait (
                                                        __tame_ev.mkevent (function (args) {
                                                            res = tame.assign (args, res);
                                                        })
                                                        ) ;
                                                        tame.callChain([__tame_k]);
                                                    };
                                                    __tame_fn_18(tame.end);
                                                    __tame_ev.trigger();
                                                };
                                                var __tame_fn_19 = function (__tame_k) {
                                                    slots [ res ] |= 4 ;
                                                    nrecv ++ ;
                                                    tame.callChain([__tame_k]);
                                                };
                                                tame.callChain([__tame_fn_17, __tame_fn_19, __tame_k]);
                                            };
                                            tame.callChain([__tame_fn_16, __tame_k]);
                                        };
                                        if (nsent - nrecv < window && nsent < n) {
                                            tame.callChain([__tame_fn_15, __tame_k]);
                                        } else {
                                            tame.callChain([__tame_fn_20, __tame_k]);
                                        }
                                    };
                                    tame.callChain([__tame_fn_14, __tame_fn_13, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            __tame_k_implicit.k_break = __tame_k;
                            __tame_k_implicit.k_continue = function() { __tame_fn_13(__tame_k); };
                            tame.callChain([__tame_fn_13, __tame_k]);
                        };
                        var __tame_fn_21 = function (__tame_k) {
                            ev ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_12, __tame_fn_21, __tame_k]);
                    };
                    tame.callChain([__tame_fn_11, __tame_k]);
                };
                tame.callChain([__tame_fn_22, __tame_k]);
            }
            ;
            
            var n = 100 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_ev = new tame.Event (__tame_k);
                    var __tame_fn_3 = function (__tame_k) {
                        window ( n , 10 ,
                        __tame_ev.mkevent ()
                        ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_3(tame.end);
                    __tame_ev.trigger();
                };
                var __tame_fn_4 = function (__tame_k) {
                    ev ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i in slots) {
            assert .equal ( slots [ i ] , 7 , "all 3 events make bitwise 7" ) ;
        }
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.3.0.tgz: package/test/cases/1.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var slots = { } ;
    
    exports [ "rendezvous & windowing example" ] = {
    
    
    run :
    function  (ev) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            function call (i, ev) {
                var __tame_this = this;
                var __tame_fn_10 = function (__tame_k) {
                    slots [ i ] = 1 ;
                    var __tame_fn_6 = function (__tame_k) {
                        var __tame_fn_7 = function (__tame_k) {
                            var __tame_defers = new tame.Defers (__tame_k);
                            var __tame_fn_8 = function (__tame_k) {
                                setTimeout (
                                __tame_defers.defer ()
                                , 10*Math . random ( ) ) ;
                                tame.callChain([__tame_k]);
                            };
                            __tame_fn_8(tame.end);
                            __tame_defers._fulfill();
                        };
                        var __tame_fn_9 = function (__tame_k) {
                            slots [ i ] |= 2 ;
                            ev ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_7, __tame_fn_9, __tame_k]);
                    };
                    tame.callChain([__tame_fn_6, __tame_k]);
                };
                tame.callChain([__tame_fn_10, __tame_k]);
            }
            ;
            function window (n, window, ev) {
                var __tame_this = this;
                var __tame_fn_22 = function (__tame_k) {
                    var rv = new tame . Rendezvous ( ) ;
                    var nsent = 0 ;
                    var nrecv = 0 ;
                    var __tame_fn_11 = function (__tame_k) {
                        var __tame_fn_12 = function (__tame_k) {
                            var __tame_k_implicit =  {};
                            var __tame_fn_13 = function (__tame_k) {
                                if (nrecv < n) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        var __tame_fn_15 = function (__tame_k) {
                                            call ( nsent , rv . id ( nsent ) .
                                            __tame_defers.defer ()
                                            ) ;
                                            nsent ++ ;
                                            tame.callChain([__tame_k]);
                                        };
                                        var __tame_fn_20 = function (__tame_k) {
                                            var res ;
                                            var __tame_fn_16 = function (__tame_k) {
                                                var __tame_fn_17 = function (__tame_k) {
                                                    var __tame_defers = new tame.Defers (__tame_k);
                                                    var __tame_fn_18 = function (__tame_k) {
                                                        rv . wait (
                                                        __tame_defers.defer (
                                                            function () {
                                                                res = arguments[0];
                                                            }
                                                        )
                                                        ) ;
                                                        tame.callChain([__tame_k]);
                                                    };
                                                    __tame_fn_18(tame.end);
                                                    __tame_defers._fulfill();
                                                };
                                                var __tame_fn_19 = function (__tame_k) {
                                                    slots [ res ] |= 4 ;
                                                    nrecv ++ ;
                                                    tame.callChain([__tame_k]);
                                                };
                                                tame.callChain([__tame_fn_17, __tame_fn_19, __tame_k]);
                                            };
                                            tame.callChain([__tame_fn_16, __tame_k]);
                                        };
                                        if (nsent - nrecv < window && nsent < n) {
                                            tame.callChain([__tame_fn_15, __tame_k]);
                                        } else {
                                            tame.callChain([__tame_fn_20, __tame_k]);
                                        }
                                    };
                                    tame.callChain([__tame_fn_14, __tame_fn_13, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            __tame_k_implicit.k_break = __tame_k;
                            __tame_k_implicit.k_continue = function() { __tame_fn_13(__tame_k); };
                            tame.callChain([__tame_fn_13, __tame_k]);
                        };
                        var __tame_fn_21 = function (__tame_k) {
                            ev ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_12, __tame_fn_21, __tame_k]);
                    };
                    tame.callChain([__tame_fn_11, __tame_k]);
                };
                tame.callChain([__tame_fn_22, __tame_k]);
            }
            ;
            
            var n = 100 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_defers = new tame.Defers (__tame_k);
                    var __tame_fn_3 = function (__tame_k) {
                        window ( n , 10 ,
                        __tame_defers.defer ()
                        ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_3(tame.end);
                    __tame_defers._fulfill();
                };
                var __tame_fn_4 = function (__tame_k) {
                    ev ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i in slots) {
            assert . equal ( slots [ i ] , 7 , "all 3 events make bitwise 7" ) ;
        }
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
